#!/bin/bash

# Fetches all running jobs on the job manager
# First cancels them, then restarts them based on the latest checkpoint ID
# If no jobs are running at the moment, will start all jobs in all environments

flinkList=$(flink list|grep RUNNING)
logFile=/opt/flink/log/daily-restart-logs

jobIds=($(echo $flinkList | awk -v RS=: -v ORS=" " '0==NR%4'))

envs=($(echo $flinkList | awk -v RS=: -v ORS=" " 'NR>1 { print $3 }'))
echo "Restarting all existing Jobs"
for ((i=0;i<${#jobIds[@]};++i)); do
  flink cancel ${jobIds[i]} &>> $logFile
  if [ ${envs[i]} == "prod05" ]
  then
    echo "Waiting for prod05 tasks to cancel for 1 minute..."
    sleep 1m
  fi

  last_checkpoint=$(curl --silent http://flink-cluster-prod-primary.cdca.int/jobs/${jobIds[i]}/checkpoints 2>&1 | jq '.latest.completed.external_path')
  echo "Restarting ${envs[i]} with checkpoint: $last_checkpoint" &>> $logFile

  flink run -s $last_checkpoint -d -c com.carbonblack.flink.EventRouterEventTime /opt/flink/lib/pv9-flink-1.150-SNAPSHOT.jar --config /opt/flink/job-config/job-${envs[i]}.yaml &>> $logFile
done
